package tests;

import entities.pkg.Theatre;
import entities.pkg.TheatreLocation;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

public class TestsRunner {
    
    private static EntityManagerFactory emf = Persistence.createEntityManagerFactory("one-to-one-cascade-overridePU");
    
    private static long LOCATION_ID = 109;;
    private static String ADDRESS = "Knoxville, TN";
    private static long THEATRE_ID = 369;
    private static String CODE = "KTN";
    
    public static void main(String args[]){
        TestsRunner runner = new TestsRunner();
        
        runner.persistTheatreAndTheatreLocation();
        runner.findTheatreReadTheatreLocation();
        runner.deleteTheatre();
        runner.CascadeDeleteShouldNotApplyOnTheatreLocation();
    }
    
    private void persistTheatreAndTheatreLocation() {
        EntityManager em = emf.createEntityManager();
        em.getTransaction().begin();
        
        TheatreLocation location = new TheatreLocation();
        location.setId(LOCATION_ID);
        location.setAddress(ADDRESS);
        
        Theatre theatre = new Theatre();
        theatre.setId(THEATRE_ID);
        theatre.setCode(CODE);
        
        theatre.setLocation(location);
        location.setTheatre(theatre);

        em.persist(theatre);
        em.getTransaction().commit();
    }

    private void findTheatreReadTheatreLocation() {
        EntityManager em = emf.createEntityManager();
        Theatre theatre = em.find(Theatre.class, THEATRE_ID);
        if (theatre.getLocation().getId()==LOCATION_ID)
            System.out.println("Cascade Persist - Theatre Location also persisted");
        else
            System.out.println("No Cascade Persist - Theatre Location failed to persist");
    }
    
    private void deleteTheatre() {
        EntityManager em = emf.createEntityManager();

        em.getTransaction().begin();
        Theatre theatre = em.find(Theatre.class, THEATRE_ID);
        em.remove(theatre);
        em.getTransaction().commit();
    }

    private void CascadeDeleteShouldNotApplyOnTheatreLocation() {
        EntityManager em = emf.createEntityManager();

        TheatreLocation location = em.find(TheatreLocation.class, LOCATION_ID);
        if (location == null)
            System.out.println("Cascade Remove - Theatre Location was deleted.");
        else
            System.out.println("No Cascade Remove - Theatre Location was NOT deleted");
    }

}
